@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-"""Omnibust v0.1.1 - A universal cachebusting script
+"""Omnibust v0.1.2 - A universal cachebusting script
 
 Omnibust will scan the files of your web project for static resources
 (js, css, png) and also for urls in your sourcecode (html, js, css, py,
@@ -442,8 +442,8 @@ def iter_refs(codefile_paths, parse_plain=True, encoding='utf-8'):
         try:
             with codecs.open(codefile_path, 'r', encoding) as fp:
                 content = fp.read()
-        except:
-            print("omnibust: error reading '%s'" % codefile_path)
+        except Exception as e:
+            print("omnibust: error reading '{0}' ('{1}')".format(codefile_path, e))
             continue
         
         for ref in parse_content_refs(content, parse_plain):
@@ -513,9 +513,6 @@ def ref_print_wrapper(refs):
         print(" %s %s" % (lineno, ref.full_ref))
         print("    ->", new_full_ref)
         yield ref, paths, new_full_ref
-    
-    if prev_codepath is None:
-        print("omnibust: nothing to cachebust")
 
 
 def busted_refs(ref_map, cfg, target_reftype):
@@ -531,10 +528,11 @@ def busted_refs(ref_map, cfg, target_reftype):
 
 
 def rewrite_content(ref, new_full_ref):
-    with open(ref_codepath(ref), 'r') as f:
+    # TODO: better handling of file encoding
+    with codecs.open(ref_codepath(ref), 'r', encoding='utf-8') as f:
         content = f.read()
 
-    with open(ref_codepath(ref), 'w') as f:
+    with codecs.open(ref_codepath(ref), 'w', encoding='utf-8') as f:
         f.write(content.replace(ref.full_ref, new_full_ref))
 
 
@@ -769,7 +767,10 @@ def init_project(args):
 def status(args, cfg):
     target_reftype = get_target_reftype(args)
     ref_map = scan_project(args, cfg)
-    list(ref_print_wrapper(busted_refs(ref_map, cfg, target_reftype)))
+    refs = list(ref_print_wrapper(busted_refs(ref_map, cfg, target_reftype)))
+    if not refs:
+        print("omnibust: nothing to cachebust")
+
 
 
 def rewrite(args, cfg):
@@ -793,6 +794,9 @@ def rewrite(args, cfg):
 
         updated_paths.update(cur_paths)
 
+    if not updated_paths:
+        print("omnibust: nothing to cachebust")
+
 
 def dispatch(args):
     cmd = get_command(args)
